% This file is part of the Attempto Parsing Engine (APE).
% Copyright 2008, Attempto Group, University of Zurich (see http://attempto.ifi.uzh.ch).
%
% The Attempto Parsing Engine (APE) is free software: you can redistribute it and/or modify it
% under the terms of the GNU Lesser General Public License as published by the Free Software
% Foundation, either version 3 of the License, or (at your option) any later version.
%
% The Attempto Parsing Engine (APE) is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
% PURPOSE. See the GNU Lesser General Public License for more details.
%
% You should have received a copy of the GNU Lesser General Public License along with the Attempto
% Parsing Engine (APE). If not, see http://www.gnu.org/licenses/.


:- module(functionwords, [
	functionword/1,
	preposition/3,
	rawnumber_number/2,
	propername_prefix/3,
	noun_prefix/3,
	verb_prefix/2,
	modif_prefix/1
	]).

/** <module> Function Words

This module stores the different kinds of function words.

@author Kaarel Kaljurand
@author Tobias Kuhn
@version 2008-03-12
*/


%% functionword(?FunctionWord) is det.
%

functionword(whose).
functionword(for).
functionword('There').
functionword(there).
functionword(and).
functionword(or).
functionword(not).
functionword(that).
functionword(than).
functionword(of).
functionword(s).
functionword('\'').
functionword('"').
functionword('/').
functionword('\\').
functionword('-').
functionword('+').
functionword('&').
functionword('*').
functionword('(').
functionword(')').
functionword('[').
functionword(']').
functionword('}').
functionword('{').
functionword('<').
functionword('=').
functionword('>').
functionword('.').
functionword('?').
functionword('!').
functionword(',').
functionword(':').
functionword('If').
functionword(if).
functionword(then).
functionword('such').
functionword('Proposition').
functionword('proposition').
functionword('Prop').
functionword('prop').
functionword('be').
functionword('isn').
functionword('aren').
functionword('doesn').
functionword('don').
functionword('_that_'). % complementizer
functionword('provably').
functionword(more).
functionword(most).
functionword(least).
functionword(less).
functionword(but).
functionword(true).
functionword(false).
functionword(possible).
functionword(necessary).
functionword('-thing').
functionword('-body').
functionword('-one').
functionword('something').
functionword('somebody').
functionword('someone').
functionword('nothing').
functionword('nobody').
functionword('noone').
functionword('everything').
functionword('everybody').
functionword('everyone').
functionword('one').
functionword('A').
functionword('All').
functionword('An').
functionword('Are').
functionword('Can').
functionword('Do').
functionword('Does').
functionword('Each').
functionword('Every').
functionword('Exactly').
functionword('He').
functionword('Her').
functionword('His').
functionword('How').
functionword('Is').
functionword('It').
functionword('Its').
functionword('Must').
functionword('No').
functionword('She').
functionword('Some').
functionword('The').
functionword('Their').
functionword('They').
functionword('What').
functionword('When').
functionword('Where').
functionword('Which').
functionword('Who').
functionword('Whose').
functionword(a).
functionword(all).
functionword(an).
functionword(are).
functionword(can).
functionword(do).
functionword(does).
functionword(each).
functionword(every).
functionword(exactly).
functionword(he).
functionword(her).
functionword(herself).
functionword(him).
functionword(himself).
functionword(his).
functionword(how).
functionword(is).
functionword(it).
functionword(its).
functionword(itself).
functionword(must).
functionword(no).
functionword(she).
functionword(some).
functionword(the).
functionword(their).
functionword(them).
functionword(themselves).
functionword(they).
functionword(what).
functionword(when).
functionword(where).
functionword(which).
functionword(who).


%% preposition(?RawPreposition, ?Preposition, ?Type) is det.
%

preposition(from, from, origin).
preposition('From', from, origin).
preposition(as, as, unknown).
preposition('As', as, unknown).
preposition(about, about, unknown).
preposition('About', about, unknown).
preposition(by, by, unknown).
preposition('By',by,unknown).
preposition(for, for, unknown).
preposition('For',for,unknown).
preposition(among, among, unknown).
preposition('Among',among,unknown).
preposition(amongst, amongst, unknown).
preposition('Amongst',amongst,unknown).
preposition(like, like, unknown).
preposition('Like',like,unknown).
preposition(without, without, unknown).
preposition('Without',without,unknown).
preposition(despite, despite, unknown).
preposition('Despite',despite,unknown).
preposition(amid, amid, unknown).
preposition('Amid',amid,unknown).
preposition(aboard, aboard, unknown).
preposition('Aboard',aboard,unknown).
preposition(in, in, location).
preposition('In',in,location).
preposition(at, at, location).
preposition('At',at,location).
preposition(on, on, location).
preposition('On',on,location).
preposition(over, over, location).
preposition('Over',over,location).
preposition(around, around, location).
preposition('Around',around,location).
preposition(between, between, location).
preposition('Between',between,location).
preposition(inside, inside, location).
preposition('Inside',inside,location).
preposition(behind, behind, location).
preposition('Behind',behind,location).
preposition(below, below, location).
preposition('Below',below,location).
preposition(beneath, beneath, location).
preposition('Beneath',beneath,location).
preposition(outside, outside, location).
preposition('Outside',outside,location).
preposition(upon, upon, location).
preposition('Upon',upon,location).
preposition(under, under, location).
preposition('Under',under,location).
preposition(above, above, location).
preposition('Above',above,location).
preposition(beside, beside, location).
preposition('Beside',besdie,location).
preposition(near, near, location).
preposition('Near',near,location).
preposition(throughout, throughout, time).
preposition('Throughout',throughout,time).
preposition(before, before, time).
preposition('Before',before,time).
preposition(after, after, time).
preposition('After',after,time).
preposition(within, within, time).
preposition('Within',within,time).
preposition(till, till, time).
preposition('Till',till,time).
preposition(until, until, time).
preposition('Until',unitil,time).
preposition(in, in, time).
preposition('In',in,time).
preposition(at, at, time).
preposition('At',at,time).
preposition(on, on, time).
preposition('On',on,time).
preposition(over, over, time).
preposition('Over',over,time).
preposition(around, around, time).
preposition('Around',around,time).
preposition(between, between, time).
preposition('Between',between,time).
preposition(to, to, direction).
preposition('To',to,direction).
preposition(into, into, direction).
preposition('Into',into,direction).
preposition(through, through, direction).
preposition('Through',through,direction).
preposition(toward, toward, direction).
preposition('Toward',toward,direction).
preposition(towards, towards, direction).
preposition('Towards',towards,direction).
preposition(onto, onto, direction).
preposition('Onto',onto,direction).
preposition(across, across, direction).
preposition('Across',across,direction).
preposition(off, off, direction).
preposition('Off',off,dircetion).
preposition(down, down, direction).
preposition('Down',down,direction).
preposition(up, up, direction).
preposition('Up',up,direction).
preposition(along, along, direction).
preposition('Along',along,direction).
preposition(past, past, direction).
preposition('Past',past,direction).
preposition(beyond, beyond, direction).
preposition('Beyond',beyond,direction).
preposition(out, out, direction).
preposition('Out',out,direction).
preposition(against, against, direction).
preposition('Against',against,direction).
preposition(alongside, alongside, direction).
preposition('Alongside',alongside,direction).
preposition(via, via, direction).
preposition('Via',via,direction).
preposition(with, with, comitative).
preposition('With', with, comitative).
preposition(during, during, duration).
preposition('During', during, duration).


%% rawnumber_number(+RawNumber:term, -Number:integer) is det.
%
% @param RawNumber is either an integer or an English word denoting a small positive integer
% @param Number is an integer
%
% Only integers 0-12 are supported as words.

rawnumber_number(RawNumber, RawNumber) :-
	number(RawNumber).

rawnumber_number(null, 0).
rawnumber_number(zero, 0).
rawnumber_number(one, 1).
rawnumber_number(two, 2).
rawnumber_number(three, 3).
rawnumber_number(four, 4).
rawnumber_number(five, 5).
rawnumber_number(six, 6).
rawnumber_number(seven, 7).
rawnumber_number(eight, 8).
rawnumber_number(nine, 9).
rawnumber_number(ten, 10).
rawnumber_number(eleven, 11).
rawnumber_number(twelve, 12).
rawnumber_number(dozen, 12).

% Capitalized versions of the number words
% as numbers can also be used at the beginning of
% the sentences, e.g. 'Four men wait.'
rawnumber_number('Null', 0).
rawnumber_number('Zero', 0).
rawnumber_number('One', 1).
rawnumber_number('Two', 2).
rawnumber_number('Three', 3).
rawnumber_number('Four', 4).
rawnumber_number('Five', 5).
rawnumber_number('Six', 6).
rawnumber_number('Seven', 7).
rawnumber_number('Eight', 8).
rawnumber_number('Nine', 9).
rawnumber_number('Ten', 10).
rawnumber_number('Eleven', 11).
rawnumber_number('Twelve', 12).
rawnumber_number('Dozen', 12).



%% propername_prefix(+Prefix:atom, +Gender:atom, +Type:atom) is det.
%% noun_prefix(+Prefix:atom, +Gender:atom, +Type:atom) is det.
%% verb_prefix(+Prefix:atom, +Type:atom) is det.
%% modif_prefix(+Prefix:atom) is det.
%
% Definition of prefixes.
% Support for words which are not in the lexicon.
% Undefined words have to start with a prefix (e.g. `n' or `v'), e.g.
% ==
% A man v:backs-up the n:web-page of the n:pizza-delivery-service.
% ==
%
% Notes:
% * syntax disambiguates (and not morphology):
% the n:blah runs. AND the n:blah run. get different readings (singular vs plural respectively)
% the n:blah v:qwerty. (gets only singular reading, since this is arrived at first)
%
% BUG: If we give up types then many prefixes will disappear.

propername_prefix(p, neutr, object).
propername_prefix(m, masc, person).
propername_prefix(f, fem, person).
propername_prefix(person, human, person).
propername_prefix(masc, masc, person).
propername_prefix(fem, fem, person).

noun_prefix(noun, neutr, na).
noun_prefix(object, neutr, object).
noun_prefix(time, neutr, time).
noun_prefix(person, human, person).
noun_prefix(masc, masc, person).
noun_prefix(fem, fem, person).
noun_prefix(n, neutr, na).
noun_prefix(o, neutr, object).
noun_prefix(t, neutr, time).
noun_prefix(m, masc, person).
noun_prefix(f, fem, person).

verb_prefix(verb, na).
verb_prefix(event, event).
verb_prefix(state, state).
verb_prefix(v, na).
verb_prefix(e, event).
verb_prefix(s, state).

modif_prefix(a).
