% This file is part of the Attempto Parsing Engine (APE).
% Copyright 2008, Attempto Group, University of Zurich (see http://attempto.ifi.uzh.ch).
%
% The Attempto Parsing Engine (APE) is free software: you can redistribute it and/or modify it
% under the terms of the GNU Lesser General Public License as published by the Free Software
% Foundation, either version 3 of the License, or (at your option) any later version.
%
% The Attempto Parsing Engine (APE) is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
% PURPOSE. See the GNU Lesser General Public License for more details.
%
% You should have received a copy of the GNU Lesser General Public License along with the Attempto
% Parsing Engine (APE). If not, see http://www.gnu.org/licenses/.


:- module(lexicon_interface, [
	adv/4,
	adv_comp/4,
	adv_sup/4,
	adj_itr/4,
	adj_itr_comp/4,
	adj_itr_sup/4,
	adj_tr/5,
	adj_tr_comp/5,
	adj_tr_sup/5,
	noun_sg/5,
	noun_pl/5,
	noun_mass/5,
	mn_sg/4,
	mn_pl/4,
	pn_sg/5,
	pn_pl/5,
	iv_finsg/4,
	iv_infpl/4,
	tv_finsg/4,
	tv_infpl/4,
	tv_pp/4,
	dv_finsg/5,
	dv_infpl/5,
	dv_pp/5,
	common_noun/1,
	verb/1,
	attributive_adjective/1
	]).


% Calls to the lexicon.
% The user lexicon (ulex) is preferred to
% the common lexicon (clex).
%
% BUG: it looks ugly, maybe there is a nicer way to do it.

adv(WordForm, Word, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
adv(WordForm, Word, Type, Comment) :- ulex:adv(WordForm, Word, Type, Comment).
adv(WordForm, Word, Type, Comment) :- clex:adv(WordForm, Word, Type, Comment).

adv_comp(WordForm, Word, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
adv_comp(WordForm, Word, Type, Comment) :- ulex:adv_comp(WordForm, Word, Type, Comment).
adv_comp(WordForm, Word, Type, Comment) :- clex:adv_comp(WordForm, Word, Type, Comment).

adv_sup(WordForm, Word, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
adv_sup(WordForm, Word, Type, Comment) :- ulex:adv_sup(WordForm, Word, Type, Comment).
adv_sup(WordForm, Word, Type, Comment) :- clex:adv_sup(WordForm, Word, Type, Comment).

adj_itr(WordForm, Word, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
adj_itr(WordForm, Word, Type, Comment) :- ulex:adj_itr(WordForm, Word, Type, Comment).
adj_itr(WordForm, Word, Type, Comment) :- clex:adj_itr(WordForm, Word, Type, Comment).

adj_itr_comp(WordForm, Word, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
adj_itr_comp(WordForm, Word, Type, Comment) :- ulex:adj_itr_comp(WordForm, Word, Type, Comment).
adj_itr_comp(WordForm, Word, Type, Comment) :- clex:adj_itr_comp(WordForm, Word, Type, Comment).

adj_itr_sup(WordForm, Word, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
adj_itr_sup(WordForm, Word, Type, Comment) :- ulex:adj_itr_sup(WordForm, Word, Type, Comment).
adj_itr_sup(WordForm, Word, Type, Comment) :- clex:adj_itr_sup(WordForm, Word, Type, Comment).

adj_tr(WordForm, Word, _Prep, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
adj_tr(WordForm, Word, Prep, Type, Comment) :-  ulex:adj_tr(WordForm, Word, Prep, Type, Comment).
adj_tr(WordForm, Word, Prep, Type, Comment) :-  clex:adj_tr(WordForm, Word, Prep, Type, Comment).

adj_tr_comp(WordForm, Word, _Prep, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
adj_tr_comp(WordForm, Word, Prep, Type, Comment) :- ulex:adj_tr_comp(WordForm, Word, Prep, Type, Comment).
adj_tr_comp(WordForm, Word, Prep, Type, Comment) :- clex:adj_tr_comp(WordForm, Word, Prep, Type, Comment).

adj_tr_sup(WordForm, Word, _Prep, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
adj_tr_sup(WordForm, Word, Prep, Type, Comment) :- ulex:adj_tr_sup(WordForm, Word, Prep, Type, Comment).
adj_tr_sup(WordForm, Word, Prep, Type, Comment) :- clex:adj_tr_sup(WordForm, Word, Prep, Type, Comment).

noun_sg(WordForm, Word, _Gender, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
noun_sg(WordForm, Word, Gender, Type, Comment) :- ulex:noun_sg(WordForm, Word, Gender, Type, Comment).
noun_sg(WordForm, Word, Gender, Type, Comment) :- clex:noun_sg(WordForm, Word, Gender, Type, Comment).

noun_pl(WordForm, Word, _Gender, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
noun_pl(WordForm, Word, Gender, Type, Comment) :- ulex:noun_pl(WordForm, Word, Gender, Type, Comment).
noun_pl(WordForm, Word, Gender, Type, Comment) :- clex:noun_pl(WordForm, Word, Gender, Type, Comment).

noun_mass(WordForm, Word, _Gender, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
noun_mass(WordForm, Word, Gender, Type, Comment) :- ulex:noun_mass(WordForm, Word, Gender, Type, Comment).
noun_mass(WordForm, Word, Gender, Type, Comment) :- clex:noun_mass(WordForm, Word, Gender, Type, Comment).

mn_sg(WordForm, Word, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
mn_sg(WordForm, Word, Type, Comment) :- ulex:mn_sg(WordForm, Word, Type, Comment).
mn_sg(WordForm, Word, Type, Comment) :- clex:mn_sg(WordForm, Word, Type, Comment).

mn_pl(WordForm, Word, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
mn_pl(WordForm, Word, Type, Comment) :- ulex:mn_pl(WordForm, Word, Type, Comment).
mn_pl(WordForm, Word, Type, Comment) :- clex:mn_pl(WordForm, Word, Type, Comment).

pn_sg(WordForm, Word, _Gender, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
pn_sg(WordForm, Word, Gender, Type, Comment) :- ulex:pn_sg(WordForm, Word, Gender, Type, Comment).
pn_sg(WordForm, Word, Gender, Type, Comment) :- clex:pn_sg(WordForm, Word, Gender, Type, Comment).

pn_pl(WordForm, Word, _Gender, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
pn_pl(WordForm, Word, Gender, Type, Comment) :- ulex:pn_pl(WordForm, Word, Gender, Type, Comment).
pn_pl(WordForm, Word, Gender, Type, Comment) :- clex:pn_pl(WordForm, Word, Gender, Type, Comment).

iv_finsg(WordForm, Word, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
iv_finsg(WordForm, Word, Type, Comment) :- ulex:iv_finsg(WordForm, Word, Type, Comment).
iv_finsg(WordForm, Word, Type, Comment) :- clex:iv_finsg(WordForm, Word, Type, Comment).

iv_infpl(WordForm, Word, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
iv_infpl(WordForm, Word, Type, Comment) :- ulex:iv_infpl(WordForm, Word, Type, Comment).
iv_infpl(WordForm, Word, Type, Comment) :- clex:iv_infpl(WordForm, Word, Type, Comment).

tv_finsg(WordForm, Word, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
tv_finsg(WordForm, Word, Type, Comment) :- ulex:tv_finsg(WordForm, Word, Type, Comment).
tv_finsg(WordForm, Word, Type, Comment) :- clex:tv_finsg(WordForm, Word, Type, Comment).

tv_infpl(WordForm, Word, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
tv_infpl(WordForm, Word, Type, Comment) :- ulex:tv_infpl(WordForm, Word, Type, Comment).
tv_infpl(WordForm, Word, Type, Comment) :- clex:tv_infpl(WordForm, Word, Type, Comment).

tv_pp(WordForm, Word, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
tv_pp(WordForm, Word, Type, Comment) :- ulex:tv_pp(WordForm, Word, Type, Comment).
tv_pp(WordForm, Word, Type, Comment) :- clex:tv_pp(WordForm, Word, Type, Comment).

dv_finsg(WordForm, Word, _Prep, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
dv_finsg(WordForm, Word, Prep, Type, Comment) :- ulex:dv_finsg(WordForm, Word, Prep, Type, Comment).
dv_finsg(WordForm, Word, Prep, Type, Comment) :- clex:dv_finsg(WordForm, Word, Prep, Type, Comment).

dv_infpl(WordForm, Word, _Prep, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
dv_infpl(WordForm, Word, Prep, Type, Comment) :- ulex:dv_infpl(WordForm, Word, Prep, Type, Comment).
dv_infpl(WordForm, Word, Prep, Type, Comment) :- clex:dv_infpl(WordForm, Word, Prep, Type, Comment).

dv_pp(WordForm, Word, _Prep, _Type, _Comment) :- var(WordForm), var(Word), !, fail.
dv_pp(WordForm, Word, Prep, Type, Comment) :- ulex:dv_pp(WordForm, Word, Prep, Type, Comment).
dv_pp(WordForm, Word, Prep, Type, Comment) :- clex:dv_pp(WordForm, Word, Prep, Type, Comment).


common_noun(WordForm) :-
	(
		noun_sg(WordForm, _, _, _, _)
	;
		noun_pl(WordForm, _, _, _, _)
	;
		noun_mass(WordForm, _, _, _, _)
	).


verb(WordForm) :-
	(
		iv_finsg(WordForm, _, _, _)
	;
		iv_infpl(WordForm, _, _, _)
	;
		tv_finsg(WordForm, _, _, _)
	;
		tv_infpl(WordForm, _, _, _)
	;
		dv_finsg(WordForm, _, _, _, _)
	;
		dv_infpl(WordForm, _, _, _, _)
	).


%% attributive_adjective(+WordForm:atom) is det.
%
% @param WordForm is an ACE token
%
% Succeeds if WordForm is an attributive adjective

attributive_adjective(WordForm) :-
	(
		adj_itr(WordForm, _, _, _)
	;
		adj_itr_comp(WordForm, _, _, _)
	;
		adj_itr_sup(WordForm, _, _, _)
	).
